package main
import (
	"fmt"
	"image"
	"os"
	"image/color"
	"image/draw"
	"image/png"
	_ "image/jpeg"
)
func main() {
	// 開くファイル名
	file, err := os.Open("/images/test.jpg")
	if err != nil {
		fmt.Println("ファイルが開けませんでした。")
		os.Exit(1)
	}
	defer file.Close()
	// JPEG画像を解析（デコード）する
	m, _, err := image.Decode(file)
	if err != nil {
		fmt.Println("画像を解析できませんでした。")
		os.Exit(1)
	}
	// 画像サイズの四角形を生成
	myImage := image.NewRGBA(m.Bounds())
	// 黒色で四角形を描画
	draw.Draw(myImage, myImage.Bounds(), m, image.Point{0, 0}, draw.Src)
	// グレースケールにする処理
	// 画像の幅を取得する
	bounds := m.Bounds()
	// 縦幅の数だけ繰り返す
	for y := bounds.Min.Y; y<bounds.Max.Y; y++ {
		// 横幅の数だけ繰り返す
		for x := bounds.Min.X; x<bounds.Max.X; x++ {
			// ピクセルの輝度を読み出し
			r, g, b, a := myImage.At(x, y).RGBA()
			// グレースケールの値を計算する
			gray := float64(g & 0xff)*0.59 + float64(r & 0xff)*0.3 + float64(b & 0xff)*0.11
			// ピクセル値を書き込み
			myImage.Set(x, y, color.RGBA{uint8(gray), uint8(gray), uint8(gray), uint8(a)})
		}
	}
	// 保存するファイル名
	savefile, err := os.Create("/images/test_gray1.png")
	if err != nil {
		fmt.Println("保存するためのファイルが作成できませんでした。")
		os.Exit(1)
	}
	defer savefile.Close()
	// PNG形式で保存する
	png.Encode(savefile, myImage)
}
